==> chromium-44.0.2403.19.tar.xz: chromium-44.0.2403.19/net/quic/crypto/common_cert_set_1.c <==
/* Copyright (c) 2013 The Chromium Authors. All rights reserved.
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */

/* This file contains common certificates. It's designed to be #included in
 * another file, in a namespace. */

#include "net/quic/crypto/common_cert_set_1a.inc"
#include "net/quic/crypto/common_cert_set_1b.inc"

static const size_t kNumCerts = 62;
static const unsigned char* const kCerts[] = {
  kDERCert0,
  kDERCert1,
  kDERCert2,
  kDERCert3,
  kDERCert4,
  kDERCert5,
  kDERCert6,
  kDERCert7,
  kDERCert8,
  kDERCert9,
  kDERCert10,
  kDERCert11,
  kDERCert12,
  kDERCert13,
  kDERCert14,
  kDERCert15,
  kDERCert16,
  kDERCert17,
  kDERCert18,
  kDERCert19,
  kDERCert20,
  kDERCert21,
  kDERCert22,
  kDERCert23,
  kDERCert24,
  kDERCert25,
  kDERCert26,
  kDERCert27,
  kDERCert28,
  kDERCert29,
  kDERCert30,
  kDERCert31,
  kDERCert32,
  kDERCert33,
  kDERCert34,
  kDERCert35,
  kDERCert36,
  kDERCert37,
  kDERCert38,
  kDERCert39,
  kDERCert40,
  kDERCert41,
  kDERCert42,
  kDERCert43,
  kDERCert44,
  kDERCert45,
  kDERCert46,
  kDERCert47,
  kDERCert48,
  kDERCert49,
  kDERCert50,
  kDERCert51,
  kDERCert52,
  kDERCert53,
  kDERCert54,
  kDERCert55,
  kDERCert56,
  kDERCert57,
  kDERCert58,
  kDERCert59,
  kDERCert60,
  kDERCert61,
};

static const size_t kLens[] = {
  897,
  911,
  985,
  989,
  1012,
  1022,
  1049,
  1055,
  1071,
  1080,
  1084,
  1088,
  1097,
  1098,
  1105,
  1107,
  1117,
  1124,
  1127,
  1133,
  1136,
  1153,
  1171,
  1171,
  1172,
  1176,
  1182,
  1188,
  1191,
  1194,
  1194,
  1199,
  1205,
  1210,
  1226,
  1236,
  1236,
  1238,
  1250,
  1254,
  1256,
  1257,
  1269,
  1270,
  1280,
  1284,
  1285,
  1287,
  1290,
  1291,
  1291,
  1294,
  1297,
  1385,
  1512,
  1520,
  1548,
  1570,
  1581,
  1628,
  1712,
  1770,
};

static const uint64 kHash = GG_UINT64_C(0xff715ce4e7e9267b);

==> chromium-49.0.2604.0.tar.xz: chromium-49.0.2604.0/net/quic/crypto/common_cert_set_1.c <==
/* Copyright (c) 2013 The Chromium Authors. All rights reserved.
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */

/* This file contains common certificates. It's designed to be #included in
 * another file, in a namespace. */

#include "net/quic/crypto/common_cert_set_1a.inc"
#include "net/quic/crypto/common_cert_set_1b.inc"

static const size_t kNumCerts = 62;
static const unsigned char* const kCerts[] = {
  kDERCert0,
  kDERCert1,
  kDERCert2,
  kDERCert3,
  kDERCert4,
  kDERCert5,
  kDERCert6,
  kDERCert7,
  kDERCert8,
  kDERCert9,
  kDERCert10,
  kDERCert11,
  kDERCert12,
  kDERCert13,
  kDERCert14,
  kDERCert15,
  kDERCert16,
  kDERCert17,
  kDERCert18,
  kDERCert19,
  kDERCert20,
  kDERCert21,
  kDERCert22,
  kDERCert23,
  kDERCert24,
  kDERCert25,
  kDERCert26,
  kDERCert27,
  kDERCert28,
  kDERCert29,
  kDERCert30,
  kDERCert31,
  kDERCert32,
  kDERCert33,
  kDERCert34,
  kDERCert35,
  kDERCert36,
  kDERCert37,
  kDERCert38,
  kDERCert39,
  kDERCert40,
  kDERCert41,
  kDERCert42,
  kDERCert43,
  kDERCert44,
  kDERCert45,
  kDERCert46,
  kDERCert47,
  kDERCert48,
  kDERCert49,
  kDERCert50,
  kDERCert51,
  kDERCert52,
  kDERCert53,
  kDERCert54,
  kDERCert55,
  kDERCert56,
  kDERCert57,
  kDERCert58,
  kDERCert59,
  kDERCert60,
  kDERCert61,
};

static const size_t kLens[] = {
  897,
  911,
  985,
  989,
  1012,
  1022,
  1049,
  1055,
  1071,
  1080,
  1084,
  1088,
  1097,
  1098,
  1105,
  1107,
  1117,
  1124,
  1127,
  1133,
  1136,
  1153,
  1171,
  1171,
  1172,
  1176,
  1182,
  1188,
  1191,
  1194,
  1194,
  1199,
  1205,
  1210,
  1226,
  1236,
  1236,
  1238,
  1250,
  1254,
  1256,
  1257,
  1269,
  1270,
  1280,
  1284,
  1285,
  1287,
  1290,
  1291,
  1291,
  1294,
  1297,
  1385,
  1512,
  1520,
  1548,
  1570,
  1581,
  1628,
  1712,
  1770,
};

static const uint64_t kHash = UINT64_C(0xff715ce4e7e9267b);
